
import pandas as pd

class OutlierHandler:
    def __init__(self, df):
        self.df = df
        
    def detect_outliers_iqr(self, df, column, threshold=1.5):
        Q1 = df[column].quantile(0.25)
        Q3 = df[column].quantile(0.75)
        IQR = Q3 - Q1
        lower_bound = Q1 - threshold * IQR
        upper_bound = Q3 + threshold * IQR
        return df[(df[column] < lower_bound) | (df[column] > upper_bound)]

    def remove_outliers(self, df, column, threshold=1.5):
        Q1 = df[column].quantile(0.25)
        Q3 = df[column].quantile(0.75)
        IQR = Q3 - Q1
        lower_bound = Q1 - threshold * IQR
        upper_bound = Q3 + threshold * IQR
        return df[(df[column] >= lower_bound) & (df[column] <= upper_bound)]




import pandas as pd

class DateTimeHandler:
    def __init__(self, df):
        self.df = df
        
    def extract_date_features(self, df, column):
        df[column] = pd.to_datetime(df[column])
        df[f'{column}_year'] = df[column].dt.year
        df[f'{column}_month'] = df[column].dt.month
        df[f'{column}_day'] = df[column].dt.day
        df[f'{column}_weekday'] = df[column].dt.weekday
        return df

    def convert_to_datetime(self, df, columns):
        for column in columns:
            df[column] = pd.to_datetime(df[column], errors='coerce')
        return df




import pandas as pd
from sklearn.preprocessing import OneHotEncoder, LabelEncoder

class CategoricalEncoder:
    def __init__(self, df):
        self.df = df
    
    def one_hot_encode(self, df, columns):
        encoder = OneHotEncoder(sparse=False, drop='first')
        encoded_columns = encoder.fit_transform(df[columns])
        df = df.drop(columns, axis=1)
        df = pd.concat([df, pd.DataFrame(encoded_columns, columns=encoder.get_feature_names_out(columns))], axis=1)
        return df

    def label_encode(self, df, columns):
        encoder = LabelEncoder()
        for column in columns:
            df[column] = encoder.fit_transform(df[column])
        return df



from setuptools import setup, find_packages

setup(
    name='DataCleaningWithPandas',
    version='0.1.9',
    description='A data preprocessing library',
    author='Muhammed Furkan Akdag & Ahmet Akif Apari',
    author_email='furkanakdag.3469@gmail.com',
    packages=find_packages(),
    python_requires='>=3.6',
    install_requires=[
        'pandas',
        'numpy',
        'scikit-learn',
        'nltk',
    ],
)



import pandas as pd

class MissingValueHandler:
    def __init__(self, df):
        self.df = df
        
    def impute_mean(self, df, columns):
        for column in columns:
            df[column].fillna(df[column].mean(), inplace=True)
        return df

    def impute_median(self, df, columns):
        for column in columns:
            df[column].fillna(df[column].median(), inplace=True)
        return df

    def impute_constant(self, df, columns, constant):
        for column in columns:
            df[column].fillna(constant, inplace=True)
        return df

    def drop_missing(self, df, threshold):
        return df.dropna(thresh=threshold)



import pandas as pd
from sklearn.preprocessing import MinMaxScaler, StandardScaler

class Scaler:
    def __init__(self, df):
        self.df = df
        
    def min_max_scale(self, df, columns):
        scaler = MinMaxScaler()
        df[columns] = scaler.fit_transform(df[columns])
        return df

    def standard_scale(self, df, columns):
        scaler = StandardScaler()
        df[columns] = scaler.fit_transform(df[columns])
        return df



import pandas as pd

class DataTypeConverter:
    def __init__(self, df):
        self.df = df
        
    def convert_to_numeric(self, df, columns):
        for column in columns:
            df[column] = pd.to_numeric(df[column], errors='coerce')
        return df

    def convert_to_categorical(self, df, columns):
        for column in columns:
            df[column] = df[column].astype('category')
        return df



from .missing_value_handler import MissingValueHandler
from .outlier_handler import OutlierHandler
from .scaler import Scaler
from .text_cleaner import TextCleaner
from .data_type_converter import DataTypeConverter
from .categorical_encoder import CategoricalEncoder
from .date_time_handler import DateTimeHandler


__version__ = "0.1.9"




import string
import nltk
from nltk.corpus import stopwords
from nltk.stem import WordNetLemmatizer

nltk.download('stopwords')
nltk.download('wordnet')

class TextCleaner:
    def __init__(self):
        self.stopwords = set(stopwords.words('english'))
        self.lemmatizer = WordNetLemmatizer()

    def remove_stopwords(self, text):
        return " ".join([word for word in text.split() if word.lower() not in self.stopwords])

    def to_lowercase(self, text):
        return text.lower()

    def remove_punctuation(self, text):
        return text.translate(str.maketrans('', '', string.punctuation))

    def lemmatize(self, text):
        return " ".join([self.lemmatizer.lemmatize(word) for word in text.split()])
